@@ -3,7 +3,7 @@
 from tkinter import messagebox
 import tkinter as tk
 from tkinter import *
-from fui.main_ui import MainUI
+from funing.fui.main_ui import MainUI
 from langcodes import Language
 import gettext
 import sys
@@ -13,9 +13,7 @@ import cv2
 from PIL import Image , ImageTk
 from funing.locale.lang import _
 from datetime import datetime , date
-import json
 from funing import settings
-import pickle
 import yaml
 import uuid
 import time
